@@ -109,8 +109,14 @@ thin_frame_by_orders <- function(d, cols, groupcol, large_count) {
 #' @param model_color color for the model curve
 #' @param wizard_color color for the "wizard" (best possible) curve
 #' @param shadow_color color for the shaded area under the curve
+#'
 #' @examples
 #'
+#' if (requireNamespace('data.table', quietly = TRUE)) {
+#'		# don't multi-thread during CRAN checks
+#' 		data.table::setDTthreads(1)
+#' }
+#'
 #' set.seed(34903490)
 #' y = abs(rnorm(20)) + 0.1
 #' x = abs(y + 0.5*rnorm(20))
@@ -346,6 +352,11 @@ makeRelativeGiniCostScorer <- function(costcol) {
 #'
 #' @examples
 #'
+#' if (requireNamespace('data.table', quietly = TRUE)) {
+#'		# don't multi-thread during CRAN checks
+#' 		data.table::setDTthreads(1)
+#' }
+#'
 #' set.seed(34903490)
 #' y = abs(rnorm(20)) + 0.1
 #' x = abs(y + 0.5*rnorm(20))
@@ -548,6 +559,11 @@ get_gainy = function(frame, xvar, truthVar, gainx) {
 #'
 #' @examples
 #'
+#' if (requireNamespace('data.table', quietly = TRUE)) {
+#'		# don't multi-thread during CRAN checks
+#' 		data.table::setDTthreads(1)
+#' }
+#'
 #' set.seed(34903490)
 #' y = abs(rnorm(20)) + 0.1
 #' x = abs(y + 0.5*rnorm(20))
@@ -620,7 +636,7 @@ GainCurvePlotWithNotation = function(frame,
     ggplot2::geom_hline(yintercept = gainy,
                         color = crosshair_color,
                         alpha = 0.5) +
-    ggplot2::scale_shape_discrete(guide = FALSE) +
+    ggplot2::scale_shape_discrete(guide = "none") +
     ggplot2::annotate(
       geom = "text",
       x = gainx + 0.01,
@@ -655,8 +671,14 @@ GainCurvePlotWithNotation = function(frame,
 #' @param ...  no unnamed argument, added to force named binding of later arguments.
 #' @param truth_target if not NULL compare to this scalar value.
 #' @param palette color palette for the model curves
+#'
 #' @examples
 #'
+#' if (requireNamespace('data.table', quietly = TRUE)) {
+#'		# don't multi-thread during CRAN checks
+#' 		data.table::setDTthreads(1)
+#' }
+#'
 #' set.seed(34903490)
 #' y = abs(rnorm(20)) + 0.1
 #' x = abs(y + 0.5*rnorm(20))
